package main

import (
  "fmt"
  "time"

  "github.com/aws/aws-sdk-go/aws/session"
  "github.com/aws/aws-sdk-go/service/ec2"
)

func main() {
  sess := session.Must(session.NewSessionWithOptions(session.Options{
    SharedConfigState: session.SharedConfigEnable,
  }))

  ec2Svc := ec2.New(sess)
  res, err := ec2Svc.DescribeInstances(nil)
  if err != nil {
    fmt.Println(err)
  }

  format := "%-14s  %-14s  %-19s  %-20s  %-13s  %s\n"
  fmt.Printf(format, "PRIVATE IP", "PUBLIC IP", "INSTANCE ID", "LAUNCH TIME", "STATE", "NAME")

  for i := range(res.Reservations) {
    inst := res.Reservations[i].Instances[0]

    publicIp := ""
    if inst.PublicIpAddress != nil {
      publicIp = *inst.PublicIpAddress
    }

    privateIp := ""
    if inst.PrivateIpAddress != nil {
      privateIp = *inst.PrivateIpAddress
    }

    name := ""
    for j := range(inst.Tags) {
      if *inst.Tags[j].Key == "Name" {
        name = *inst.Tags[j].Value
      }
    }

    // launchTime := inst.LaunchTime.Format(time.Stamp)
    // launchTime := inst.LaunchTime.Format("2006-01-02 08:28:32.000Z")
    launchTime := inst.LaunchTime.Format(time.RFC3339)
    stateName  := *inst.State.Name
    instanceId := *inst.InstanceId

    // if stateName == "terminated" && name == "" {
    //   continue
    // }

    if name == "" {
      continue
    }

    fmt.Printf(format, privateIp, publicIp, instanceId, launchTime, stateName, name)
  }
}
